@@ -18,8 +18,11 @@ limitations under the License.
 
 import json
 import os
+import six
 import utils
 
+from freezer.utils.utils import DateTime
+
 from prettytable import PrettyTable
 
 try:
@@ -28,7 +31,7 @@ except Exception:
     def pprint(doc):
         print(json.dumps(doc, indent=4))
 
-from freezer.utils import create_dir
+from freezer.utils import utils as freezer_utils
 
 
 def do_session_remove_job(client, args):
@@ -68,7 +71,7 @@ def do_session_list_job(client, args):
     session_doc = client.sessions.get(args.session_id)
     jobs = session_doc.get('jobs', {})
     table = PrettyTable(["job_id", "status", "result", "client_id"])
-    for job_id, job_data in jobs.iteritems():
+    for job_id, job_data in six.iteritems(jobs):
         table.add_row([job_id,
                        job_data['status'],
                        job_data['result'],
@@ -93,7 +96,7 @@ def do_session_create(client, args):
         raise Exception("Parameter --file required")
     session_doc = utils.load_doc_from_json_file(args.fname)
     session_id = client.sessions.create(session_doc)
-    print ("Created session {0}".format(session_id))
+    print("Created session {0}".format(session_id))
 
 
 def do_session_get(client, args):
@@ -162,18 +165,18 @@ def do_job_start(client, args):
     if not args.job_id:
         raise Exception("Parameter --job required")
     client.jobs.start_job(args.job_id)
-    print("Job {0} started".format(args.job_id))
+    print("Start request sent for job {0}".format(args.job_id))
 
 
 def do_job_stop(client, args):
     if not args.job_id:
         raise Exception("Parameter --job required")
     client.jobs.stop_job(args.job_id)
-    print("Job {0} stopped".format(args.job_id))
+    print("Stop request sent for job {0}".format(args.job_id))
 
 
 def do_job_download(client, args):
-    create_dir(args.jobs_dir, do_log=True)
+    freezer_utils.create_dir(args.jobs_dir, do_log=True)
     for doc in _job_list(client, args):
         fname = os.path.normpath('{0}/job_{1}.conf'.
                                  format(args.jobs_dir, doc['job_id']))
@@ -190,21 +193,22 @@ def do_job_upload(client, args):
 
 
 def _job_list(client, args):
+    list_func = client.jobs.list_all if args.all else client.jobs.list
     search = {}
     if args.active_only:
         search = {"match_not": [{"status": "completed"}]}
-    client_docs = client.jobs.list(search=search)
+    client_docs = list_func(search=search)
     offset = 0
     while client_docs:
         offset += len(client_docs)
         for doc in client_docs:
             yield doc
-        client_docs = client.jobs.list(offset=offset, search=search)
+        client_docs = list_func(offset=offset, search=search)
     raise StopIteration
 
 
 def do_job_list(client, args):
-    table = PrettyTable(["job_id", "description", "# actions",
+    table = PrettyTable(["job_id", "client-id", "description", "# actions",
                          "status", "event", "result", "session_id"])
     for doc in _job_list(client, args):
         job_scheduling = doc.get('job_schedule', {})
@@ -212,6 +216,7 @@ def do_job_list(client, args):
         job_event = job_scheduling.get('event', '')
         job_result = job_scheduling.get('result', '')
         table.add_row([doc['job_id'],
+                       doc.get('client_id'),
                        doc.get('description', ''),
                        len(doc.get('job_actions', [])),
                        job_status,
@@ -234,3 +239,48 @@ def do_client_list(client, args):
                            client_doc.get('description', '')])
         l = client.registration.list(offset=offset)
     print(table)
+
+
+def do_backup_list(client, args):
+    list_func = client.backups.list_all if args.all else client.backups.list
+    if args.long:
+        fields = ["backup uuid", "job-id", "client-id", "container",
+                  "hostname", "backup name", "timestamp", "level", "path"]
+    else:
+        fields = ["backup uuid", "container", "backup name", "timestamp",
+                  "level", "path"]
+    table = PrettyTable(fields)
+    l = list_func()
+    offset = 0
+    while l:
+        offset += len(l)
+        for doc in l:
+            metadata_doc = doc['backup_metadata']
+            timestamp = int(metadata_doc.get('time_stamp', 0))
+            if args.long:
+                row = [doc['backup_uuid'],
+                       metadata_doc.get('job_id', ''),
+                       metadata_doc.get('client_id', ''),
+                       metadata_doc.get('container', ''),
+                       metadata_doc.get('hostname', ''),
+                       metadata_doc.get('backup_name', ''),
+                       str(DateTime(timestamp)),
+                       metadata_doc.get('curr_backup_level', ''),
+                       metadata_doc.get('fs_real_path', '')]
+            else:
+                row = [doc['backup_uuid'],
+                       metadata_doc.get('container', ''),
+                       metadata_doc.get('backup_name', ''),
+                       str(DateTime(timestamp)),
+                       metadata_doc.get('curr_backup_level', ''),
+                       metadata_doc.get('fs_real_path', '')]
+            table.add_row(row)
+        l = list_func(offset=offset)
+    print(table)
+
+
+def do_job_abort(client, args):
+    if not args.job_id:
+        raise Exception("Parameter --job required")
+    client.jobs.abort_job(args.job_id)
+    print("Abort request sent for job {0}".format(args.job_id))
