@@ -17,10 +17,18 @@ limitations under the License.
 
 import json
 import os
+import psutil
+import signal
 import socket
-import freezer.apiclient.exceptions
 import uuid
 
+
+from oslo_log import log
+
+import freezer.apiclient.exceptions
+
+LOG = log.getLogger(__name__)
+
 CONFIG_FILE_EXT = '.conf'
 
 
@@ -34,9 +42,9 @@ def do_register(client, args=None):
             client.registration.create(client_info)
         except freezer.apiclient.exceptions.ApiClientException as e:
             if e.status_code == 409:
-                print "Client already registered"
-            return os.EX_CANTCREAT
-        return os.EX_OK
+                print("Client already registered")
+            return 73  # os.EX_CANTCREAT
+        return 0  # os.EX_OK
 
 
 def find_config_files(path):
@@ -60,7 +68,7 @@ def load_doc_from_json_file(fname, debug=False):
         except Exception as e:
             raise Exception("Unable to load conf file. {0}".format(e))
         if debug:
-            print "File {0} loaded: ".format(fname)
+            print("File {0} loaded: ".format(fname))
         return doc
 
 
@@ -68,7 +76,7 @@ def save_doc_to_json_file(doc, fname, debug=False):
     with open(fname, 'w') as fd:
         json.dump(doc, fd, indent=4)
     if debug:
-        print 'Saved doc to file: {0}'.format(fname)
+        print('Saved doc to file: {0}'.format(fname))
 
 
 def get_jobs_from_disk(path):
@@ -98,3 +106,15 @@ def get_active_jobs_from_api(client):
             break
         offset += len(jobs)
     return job_list
+
+
+def terminate_subprocess(pid, name):
+    try:
+        process = psutil.Process(pid)
+        if process.name.startswith(name):
+            os.kill(pid, signal.SIGTERM)
+        else:
+            LOG.warning('The name {} does not match the pid {}'.format(
+                name, pid))
+    except Exception:
+        LOG.debug('Process {} does not exists anymore'.format(pid))
